# redcap-toolbox
Python package of REDCap tools

## Installing REDCap Toolbox and Supported Versions

redcap-toolbox is available on PyPI:

```console
$ pip install redcap-toolbox
```

redcap-toolbox officially supports Python 3.8+.